@@ -3,10 +3,8 @@
 /**
  * Folders Access Control Lists Management (RFC4314, RFC2086)
  *
- * @version @package_version@
  * @author Aleksander Machniak <alec@alec.pl>
  *
- *
  * Copyright (C) 2011-2012, Kolab Systems AG
  *
  * This program is free software: you can redistribute it and/or modify
@@ -123,7 +121,7 @@ class acl extends rcube_plugin
                     $group_id = is_array($record[$group_field]) ? $record[$group_field][0] : $record[$group_field];
 
                     if ($group) {
-                        $users[] = array('name' => ($prefix ? $prefix : '') . $group_id, 'display' => $group);
+                        $users[] = array('name' => ($prefix ?: '') . $group_id, 'display' => $group, 'type' => 'group');
                         $keys[]  = $group;
                     }
                 }
@@ -251,6 +249,11 @@ class acl extends rcube_plugin
         // Get supported rights
         $supported = $this->rights_supported();
 
+        // give plugins the opportunity to adjust this list
+        $data = $this->rc->plugins->exec_hook('acl_rights_supported',
+            array('rights' => $supported, 'folder' => $this->mbox, 'labels' => array()));
+        $supported = $data['rights'];
+
         // depending on server capability either use 'te' or 'd' for deleting msgs
         $deleteright = implode(array_intersect(str_split('ted'), $supported));
 
@@ -281,18 +284,22 @@ class acl extends rcube_plugin
             'other' => preg_replace('/[lrswi'.$deleteright.']/', '', implode($supported)),
         );
 
-        foreach ($items as $key => $val) {
+        // give plugins the opportunity to adjust this list
+        $data = $this->rc->plugins->exec_hook('acl_rights_simple',
+            array('rights' => $items, 'folder' => $this->mbox, 'labels' => array(), 'titles' => array()));
+
+        foreach ($data['rights'] as $key => $val) {
             $id = "acl$key";
             $ul .= html::tag('li', null,
                 $input->show('', array(
                     'name' => "acl[$val]", 'value' => $val, 'id' => $id))
-                . html::label(array('for' => $id, 'title' => $this->gettext('longacl'.$key)),
-                    $this->gettext('acl'.$key)));
+                . html::label(array('for' => $id, 'title' => $data['titles'][$key] ?: $this->gettext('longacl'.$key)),
+                    $data['labels'][$key] ?: $this->gettext('acl'.$key)));
         }
 
         $out .= "\n" . html::tag('ul', $attrib, $ul, html::$common_attrib);
 
-        $this->rc->output->set_env('acl_items', $items);
+        $this->rc->output->set_env('acl_items', $data['rights']);
 
         return $out;
     }
@@ -379,6 +386,11 @@ class acl extends rcube_plugin
         // Get supported rights and build column names
         $supported = $this->rights_supported();
 
+        // give plugins the opportunity to adjust this list
+        $data = $this->rc->plugins->exec_hook('acl_rights_supported',
+            array('rights' => $supported, 'folder' => $this->mbox, 'labels' => array()));
+        $supported = $data['rights'];
+
         // depending on server capability either use 'te' or 'd' for deleting msgs
         $deleteright = implode(array_intersect(str_split('ted'), $supported));
 
@@ -398,6 +410,11 @@ class acl extends rcube_plugin
                 'delete' => $deleteright,
                 'other' => preg_replace('/[lrswi'.$deleteright.']/', '', implode($supported)),
             );
+
+            // give plugins the opportunity to adjust this list
+            $data = $this->rc->plugins->exec_hook('acl_rights_simple',
+                array('rights' => $items, 'folder' => $this->mbox, 'labels' => array()));
+            $items = $data['rights'];
         }
 
         // Create the table
@@ -407,7 +424,7 @@ class acl extends rcube_plugin
         // Create table header
         $table->add_header('user', $this->gettext('identifier'));
         foreach (array_keys($items) as $key) {
-            $label = $this->gettext('shortacl'.$key);
+            $label = $data['labels'][$key] ?: $this->gettext('shortacl'.$key);
             $table->add_header(array('class' => 'acl'.$key, 'title' => $label), $label);
         }
 
@@ -477,6 +494,13 @@ class acl extends rcube_plugin
                 if (!strpos($user, '@') && ($realm = $this->get_realm())) {
                     $user .= '@' . rcube_utils::idn_to_ascii(preg_replace('/^@/', '', $realm));
                 }
+
+                // Make sure it's valid email address to prevent from "disappearing folder"
+                // issue in Cyrus IMAP e.g. when the acl user identifier contains spaces inside.
+                if (strpos($user, '@') && !rcube_utils::check_email($user, false)) {
+                    $user = null;
+                }
+
                 $username = $user;
             }
 
@@ -544,7 +568,7 @@ class acl extends rcube_plugin
 
         $this->mbox = trim(rcube_utils::get_input_value('_mbox', rcube_utils::INPUT_GPC, true)); // UTF7-IMAP
         $advanced   = trim(rcube_utils::get_input_value('_mode', rcube_utils::INPUT_GPC));
-        $advanced   = $advanced == 'advanced' ? true : false;
+        $advanced   = $advanced == 'advanced';
 
         // Save state in user preferences
         $this->rc->user->save_prefs(array('acl_advanced_mode' => $advanced));
@@ -594,7 +618,7 @@ class acl extends rcube_plugin
      * @param array $acl1 ACL rights array (or string)
      * @param array $acl2 ACL rights array (or string)
      *
-     * @param int Comparision result, 2 - full match, 1 - partial match, 0 - no match
+     * @param int Comparison result, 2 - full match, 1 - partial match, 0 - no match
      */
     function acl_compare($acl1, $acl2)
     {
@@ -720,7 +744,11 @@ class acl extends rcube_plugin
         $config['fieldmap']['uid']  = $uid_field;
 
         // search in UID and name fields
-        $config['search_fields']   = array_values($config['fieldmap']);
+        // $name_field can be in a form of <field>:<modifier> (#1490591)
+        $name_field = preg_replace('/:.*$/', '', $name_field);
+        $search     = array_unique(array($name_field, $uid_field));
+
+        $config['search_fields']   = $search;
         $config['required_fields'] = array($uid_field);
 
         // set search filter
