@@ -4,10 +4,10 @@
  * ZipDownload
  *
  * Plugin to allow the download of all message attachments in one zip file
- * and downloading of many messages in one go.
+ * and also download of many messages in one go.
  *
- * @version 3.0
  * @requires php_zip extension (including ZipArchive class)
+ *
  * @author Philip Weir
  * @author Thomas Bruderli
  * @author Aleksander Machniak
@@ -15,8 +15,14 @@
 class zipdownload extends rcube_plugin
 {
     public $task = 'mail';
+
     private $charset = 'ASCII';
 
+    private $names = array();
+
+    // RFC4155: mbox date format
+    const MBOX_DATE_FORMAT = 'D M d H:i:s Y';
+
     /**
      * Plugin initialization
      */
@@ -63,7 +69,7 @@ class zipdownload extends rcube_plugin
                 '_action' => 'plugin.zipdownload.attachments',
                 '_mbox'   => $rcmail->output->env['mailbox'],
                 '_uid'    => $rcmail->output->env['uid'],
-            ));
+            ), false, false, true);
 
             $link = html::a(array('href' => $href, 'class' => 'button zipdownload'),
                 rcube::Q($this->gettext('downloadall'))
@@ -119,7 +125,11 @@ class zipdownload extends rcube_plugin
      */
     public function download_attachments()
     {
-        $rcmail    = rcmail::get_instance();
+        $rcmail = rcmail::get_instance();
+
+        // require CSRF protected request
+        $rcmail->request_security_check(rcube_utils::INPUT_GET);
+
         $imap      = $rcmail->get_storage();
         $temp_dir  = $rcmail->config->get('temp_dir');
         $tmpfname  = tempnam($temp_dir, 'zipdownload');
@@ -133,18 +143,8 @@ class zipdownload extends rcube_plugin
         foreach ($message->attachments as $part) {
             $pid      = $part->mime_id;
             $part     = $message->mime_parts[$pid];
-            $filename = $part->filename;
+            $disp_name = $this->_create_displayname($part);
 
-            if ($filename === null || $filename === '') {
-                $ext      = (array) rcube_mime::get_mime_extensions($part->mimetype);
-                $ext      = array_shift($ext);
-                $filename = $rcmail->gettext('messagepart') . ' ' . $pid;
-                if ($ext) {
-                    $filename .= '.' . $ext;
-                }
-            }
-
-            $disp_name   = $this->_convert_filename($filename);
             $tmpfn       = tempnam($temp_dir, 'zipattach');
             $tmpfp       = fopen($tmpfn, 'w');
             $tempfiles[] = $tmpfn;
@@ -156,7 +156,8 @@ class zipdownload extends rcube_plugin
 
         $zip->close();
 
-        $filename = ($message->subject ? $message->subject : 'roundcube') . '.zip';
+        $filename = ($this->_filename_from_subject($message->subject) ?: 'attachments') . '.zip';
+
         $this->_deliver_zipfile($tmpfname, $filename);
 
         // delete temporary files from disk
@@ -174,14 +175,53 @@ class zipdownload extends rcube_plugin
     {
         $rcmail = rcmail::get_instance();
 
-        if ($rcmail->config->get('zipdownload_selection') && !empty($_POST['_uid'])) {
-            $messageset = rcmail::get_uids();
-            if (sizeof($messageset)) {
+        if ($rcmail->config->get('zipdownload_selection')) {
+            $messageset = rcmail::get_uids(null, null, $multi, rcube_utils::INPUT_POST);
+            if (count($messageset)) {
                 $this->_download_messages($messageset);
             }
         }
     }
 
+    /**
+     * Create and get display name of attachment part to add on zip file
+     *
+     * @param $part stdClass Part of attachment on message
+     *
+     * @return string Display name of attachment part
+     */
+    private function _create_displayname($part)
+    {
+        $rcmail    = rcmail::get_instance();
+        $filename = $part->filename;
+
+        if ($filename === null || $filename === '') {
+            $ext      = (array) rcube_mime::get_mime_extensions($part->mimetype);
+            $ext      = array_shift($ext);
+            $filename = $rcmail->gettext('messagepart') . ' ' . $part->mime_id;
+            if ($ext) {
+                $filename .= '.' . $ext;
+            }
+        }
+
+        $displayname = $this->_convert_filename($filename);
+
+        /**
+         * Adding a number before dot of extension on a name of file with same name on zip
+         * Ext: attach(1).txt on attach filename that has a attach.txt filename on same zip
+         */
+        if (isset($this->names[$displayname])) {
+            list($filename, $ext) = preg_split("/\.(?=[^\.]*$)/", $displayname);
+            $displayname = $filename . '(' . ($this->names[$displayname]++) . ').' . $ext;
+            $this->names[$displayname] = 1;
+        }
+        else {
+            $this->names[$displayname] = 1;
+        }
+
+        return $displayname;
+    }
+
     /**
      * Helper method to packs all the given messages into a zip archive
      *
@@ -220,17 +260,22 @@ class zipdownload extends rcube_plugin
                 $headers = $imap->get_message_headers($uid);
 
                 if ($mode == 'mbox') {
+                    // Sender address
                     $from = rcube_mime::decode_address_list($headers->from, null, true, $headers->charset, true);
                     $from = array_shift($from);
+                    $from = preg_replace('/\s/', '-', $from);
 
-                    // Mbox format header
-                    // @FIXME: \r\n or \n
-                    // @FIXME: date format
+                    // Received (internal) date
+                    $date = rcube_utils::anytodatetime($headers->internaldate);
+                    if ($date) {
+                        $date->setTimezone(new DateTimeZone('UTC'));
+                        $date = $date->format(self::MBOX_DATE_FORMAT);
+                    }
+
+                    // Mbox format header (RFC4155)
                     $header = sprintf("From %s %s\r\n",
-                        // replace spaces with hyphens
-                        $from ? preg_replace('/\s/', '-', $from) : 'MAILER-DAEMON',
-                        // internaldate
-                        $headers->internaldate
+                        $from ?: 'MAILER-DAEMON',
+                        $date ?: ''
                     );
 
                     fwrite($tmpfp, $header);
@@ -243,12 +288,11 @@ class zipdownload extends rcube_plugin
                     fwrite($tmpfp, "\r\n");
                 }
                 else { // maildir
-                    $subject = rcube_mime::decode_mime_string((string)$headers->subject);
+                    $subject = rcube_mime::decode_header($headers->subject, $headers->charset);
+                    $subject = $this->_filename_from_subject(mb_substr($subject, 0, 16));
                     $subject = $this->_convert_filename($subject);
-                    $subject = substr($subject, 0, 16);
 
-                    $disp_name = ($subject ? $subject : 'message_rfc822') . ".eml";
-                    $disp_name = $path . $uid . "_" . $disp_name;
+                    $disp_name = $path . $uid . ($subject ? " $subject" : '') . '.eml';
 
                     $tmpfn = tempnam($temp_dir, 'zipmessage');
                     $tmpfp = fopen($tmpfn, 'w');
@@ -313,9 +357,19 @@ class zipdownload extends rcube_plugin
      */
     private function _convert_filename($str)
     {
-        $str = rcube_charset::convert($str, RCUBE_CHARSET, $this->charset);
+        $str = strtr($str, array(':' => '', '/' => '-'));
 
-        return strtr($str, array(':' => '', '/' => '-'));
+        return rcube_charset::convert($str, RCUBE_CHARSET, $this->charset);
+    }
+
+    /**
+     * Helper function to convert message subject into filename
+     */
+    private function _filename_from_subject($str)
+    {
+        $str = preg_replace('/[\t\n\r\0\x0B]+\s*/', ' ', $str);
+
+        return trim($str, " ./_");
     }
 }
 
